@@ -203,7 +203,8 @@ class ServerBlocking(ServerBase):
         )
 
     def files(self, hide_default: bool = False, path: str = None,
-              file_sizes: bool = False
+              file_sizes: bool = False,
+              deleted_files: bool = False
               ) -> Generator[FileModel, None, None]:
         """Used to list files.
 
@@ -215,6 +216,8 @@ class ServerBlocking(ServerBase):
             Path to use as root, by default None
         file_sizes : bool, optional
             by default False
+        deleted_files : bool, optional
+            Include deleted files in list, by default False
 
         Yields
         ------
@@ -228,6 +231,7 @@ class ServerBlocking(ServerBase):
                 "hide_default_files": hide_default,
                 "path": path,
                 "with_filesizes": file_sizes,
+                "include_deleted_files": deleted_files
             },
         )
 
